@@ -7,18 +7,16 @@ test_that(desc="baseURL 1",{
   
   skip_on_cran()
   
+  suppressWarnings(
   api_tests_get_pxweb_metadata_baseURL <- list(
     list(baseURL = paste0(pxweb_api$new("api.scb.se")$base_url(language = "sv"), "/ssd"),
          test_dims = c(21, 4)),
     list(baseURL = paste0(pxweb_api$new("api.scb.se")$base_url(), "/ssd"),
          test_dims = c(17, 4))
-  )
+  ))
   
   for (test in api_tests_get_pxweb_metadata_baseURL){
-    expect_that({
-      test_file <- get_pxweb_metadata(baseURL = test$baseURL)
-    }, not(throws_error()))
-    
+    expect_warning(test_file <- get_pxweb_metadata(baseURL = test$baseURL), regexp = "deprecated")
     expect_that(test_file, is_a("data.frame"), info = test$baseURL)
     expect_that(dim(test_file), is_equivalent_to(test$test_dims))
   }
@@ -42,10 +40,7 @@ test_that(desc="baseURL 2",{
   )
 
   for (test in api_tests_get_pxweb_metadata_path){
-    expect_that({
-      api_test_file <- get_pxweb_metadata(path = test)
-    }, not(throws_error()))
-    
+    expect_warning(api_test_file <- get_pxweb_metadata(path = test), regexp = "deprecated")
     expect_is(object = api_test_file$variables$variables[[1]], "list")
   }
 })
